#
# spec file for package urh
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2017-2023, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           urh
Version:        2.9.6
Release:        2.4
Summary:        Tool for investigating unknown wireless protocols
License:        GPL-3.0-only
Group:          Productivity/Hamradio/Other
URL:            https://github.com/jopohl/urh
Source:         https://github.com/jopohl/urh/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libiio-devel
BuildRequires:  limesuite-devel
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  python3-PyAudio
BuildRequires:  python3-devel >= 3.4
BuildRequires:  python3-numpy
BuildRequires:  python3-numpy-devel
BuildRequires:  python3-qt5
BuildRequires:  python3-setuptools
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(libairspy)
BuildRequires:  pkgconfig(libbladeRF)
BuildRequires:  pkgconfig(libhackrf)
BuildRequires:  pkgconfig(librtlsdr)
BuildRequires:  pkgconfig(uhd)
Requires:       python3-PyAudio
Requires:       python3-numpy
Requires:       python3-psutil
Requires:       python3-pyzmq
Requires:       python3-qt5
Recommends:     inspectrum
Recommends:     rfcat
%if 0%{?suse_version} <= 1500
BuildRequires:  python3-Cython
Requires:       python3-Cython
%else
BuildRequires:  python3-Cython0
Requires:       python3-Cython0
%endif

%description
The Universal Radio Hacker is a software for investigating unknown wireless
protocols.

%prep
%setup -q

%build
%python3_build \
  --with-airspy \
  --with-bladerf \
  --with-hackrf \
  --with-limesdr \
  --with-rtlsdr \
  --with-usrp \
  --with-plutosdr

%install
%python3_install
%fdupes %{buildroot}%{python3_sitearch}
install -Dpm 0644 data/icons/appicon.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/urh.svg
%suse_update_desktop_file -i -r urh "Network;HamRadio"

%files
%license LICENSE
%doc README.md
%{_bindir}/urh
%{_bindir}/urh_cli
%{_datadir}/icons/hicolor/scalable/apps/urh.svg
%{_datadir}/applications/urh.desktop
%{python3_sitearch}/urh
%{python3_sitearch}/urh-%{version}-py%{py3_ver}.egg-info

%changelog
* Mon Jul 29 2024 Frank Kunz <mailinglists@kunz-im-inter.net>
- Enable PlutoSDR support
* Sun Mar 17 2024 Dirk Müller <dmueller@suse.com>
- update to 2.9.6:
  * Blacken code
  * Feature/signal real timestamp
  * Update LICENSE and CI
* Mon Oct 30 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 2.9.5
  * Fix error in WSPChecksum.
  * Bias-T checkbox for RTL-SDR device settings screen.
  * Add noexcept to fix compiling of cythonext.
* Sat Oct 14 2023 munix9@googlemail.com
- Fix build on Factory/TW: requires python3-Cython0
* Sat Jan 28 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 2.9.4
  * 'Remove Carrier' encoding truncates initial input.
  * Add I/Q view.
  * Refresh protocol view also when hidden.
  * Adding Save As pcapng for ProtocolAnalyzer.
  * Keep Y-Scale when showing/hiding demodulated view.
  * Fix .sub file RAW_data strip.
  * Add rad1o support.
  * Fix error when selecting large ranges in Interpretation.
  * Allow configuration of fractional font sizes.
- Drop urh-rpmlintrc
* Mon Mar  7 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 2.9.3
  * add bias tee check box on device settings.
  * add category HamRadio to desktop file.
  * Signal: retain the sample_rate on create_new.
  * Simulation fix: use sending device dtype for modulation.
  * Variable type mismatch.
  * remove HackRF anti-freeze timeouts in places that do not
    require them.
  * add b before data string.
  * get magnitudes in cython for less memory consumption.
  * join simulation thread when simulation stopped.
  * add default noise threshold setting.
  * Fix cython warnings.
  * set BladeRF min sample rate to 520.834 kHz.
  * fix #933 improve y-scale in SendRecvDialog.
* Sat Apr 17 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2.9.2
  * allow incomplete complex files to load fix #848
  * Use list for checksum data_ranges
* Wed Dec 30 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.9.1
  * use *.wav format for demodulated signal export.
  * change separation colors to green and magenta.
  * fix disappearing separation area in demod view.
  * fix overflow in AutoInterpretation for certain signals.
* Sat Nov 28 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.9.0
  * Avoid graph overlapping legend in spectrum analyzer.
  * Improve Auto Interpretation Performance.
  * Improve sdr check fix.
  * Use costas loop for PSK demod.
  * Consider checksum label in copy operation.
* Tue Sep  8 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.8.9
  * make HackRF bias tee configurable.
  * Fix deprecation warnings due to invalid escape sequences.
  * Use ElementTree instead of deprecated cElementTree.
  * Refactor FileOperator.
  * properly remember size and position of dialogs fix.
  * add De Bruijn fuzzing.
  * add support for already demodulated signals.
  * Remove NRZ-I to prevent mixing with NRZ + Invert, clarify names.
* Sun May 17 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.8.8
  * support for complex16u (2xuint8) signals.
  * Remove padding when drawing signals and remove autofit -> Weak
    captures are visible at a glance, use Y-Scale instead.
* Mon Apr 27 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.8.7
  * improve pyinstaller_helper.py
  * nicer output for device log in dialogs
  * enforce smaller headers -> more data visible in table views
  * update README.md
  * only close current project if new one requested
  * remove parallelization in ExtensionHelper.py [ #761 ]
* Fri Apr 17 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.8.6
  * remove superfluous os.join
  * Improve appicon_big
  * New logo and icon (#757)
  * fix attribute assignment
  * use more recent UHD version
* Tue Mar 24 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.8.5
  * Beautify LFSR implementation
  * Fix decoding UI
  * Overhaul GNU Radio backend (ready for gr 3.8)
  * improve waiting in unittests
* Sat Mar  7 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.8.4
  * fix message break plugin
  * Close old project only when new project acknowledged
  * build sequentially in pyinstaller_helper.py
  * UI: Updated capitalization of GNU Radio
  * make include path in rebuild configurable
  * make combobox for device selection editable
* Wed Feb 26 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.8.3
  * allow more granular values in spinboxes
  * Show if demodulation is in progress
  * add environment variables to set API version explicitly
  * centralize setting operations + rename constants.py->settings.py
* Mon Jan  6 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 2.8.2
  * Fix some typos
  * Ensure every message has a message type after awre
  * increase range for samples_per_symbol (fix #699)
* Sat Nov 23 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.8.1
  * fix PSK threshold in AInterpretation
  * remove randomness when equally common modulations found
  * improve performance of AInterpretation for long signals
  * update ranges for BladeRF
  * Update README.md
* Sun Oct 20 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.8.0
  * update filter dialog UI
  * fix crash when creating new project with compressed signal
    loaded
  * Add GUI for higher order modulations
  * Update PSK Demod routine to support higher order PSK
* Sun Aug 25 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.7.5
  * Fix bug in FSK modulation: remove spiky jumps
  * Add missing update when deleting bits
  * Add hidden import
  * make subdevice and antenna for usrp configurable
  * make analysis look better in lower resolutions
* Wed Jun 26 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.7.2
  * Show shortcuts in context menus if possible
  * Refactor demod backend
  * Add oqpsk modulation in backend
  * Fix crash when running spectrum dialog for long time
  * Improve usability of Decoding
  * Make modulation backend more generic
  * Several fixes
* Sat Jun  1 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.7.0
  * This release brings #652 which uses native IQ formats of SDRs.
    This improves performance and reduces RAM requirements when
    recording and sending with native backend.
* Mon May 20 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.6.0
  * This release greatly enhances the capabilities of automatic label
    and message type inference. Preamble, Synchronization, Address
    (SRC/DST), Sequence Number and Checksum labels are now assigned
    automatically when hitting the Analyze button.
  Further Changes:
  * More accurate logic analysis
  * Fix parameters of auto interpretation for better PSK detection
  * Fix appearance of message type edit button in dark themes
  * Fix error with message length divisor
* Wed Apr  3 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.5.7
  * Improve dialog construction to prevent error on KDE
  * Increase frequency range of PlutoSDR
  * Fix crash when showing diff of empty protocol
  * Create directory before to prevent error with multiprocessing
* Sun Feb 24 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.5.6
  * fix center detection crash on special signals
* Tue Jan 22 2019 mardnh@gmx.de
- Upstream changed license terms
  https://github.com/jopohl/urh/commit/2ce8174330fd14adfb5642affea6d3f4f1693213
  Correct license tag:
  * "Apache-2.0 AND GPL-2.0-only" -> "GPL-3.0-only"
* Sat Jan 19 2019 mardnh@gmx.de
- Update to version 2.5.5
  * refactor name filters
  * Add .cu8 .cs8 format alias
  * remove MAX_MESSAGE_SAMPLES threshold in auto interpretation
  * add user feedback if auto detection fails
  * improve max memory allocation on 32 bit
  * Make auto interpretation work in live mode during simulation
* Tue Jan  8 2019 mardnh@gmx.de
- Update to version 2.5.4
  * Test release only - no changes for users
- Update to version 2.5.3
  * fix crash when using spectrum analyzer with GNU Radio backend
* Wed Dec 12 2018 mardnh@gmx.de
- Update to version 2.5.2
  Bugfixes
  * prevent crash in substitution encoding
  * consider alignment offset when showing selected labels
  Adjustments
  * remove Save and Close of fuzzing dialog, as closing means
    saving here anyway
  New features
  * make application font size configurable in Options -> View
* Sun Nov 25 2018 mardnh@gmx.de
- Update to version 2.5.1
  * improve stability when capturing with SoundCard
  * stop simulation instantly after finishing
* Mon Nov 19 2018 mardnh@gmx.de
- Update to version 2.5.0
  * Add native support for PlutoSDR
  * save button was not shown when change on saved signal was undone
  Bugfixes
  * y scale got falsely reset on save
* Sun Nov 11 2018 mardnh@gmx.de
- Update to version 2.4.2
  * enhance settings for RTL-SDR
  * ergonomic improvements
  Bugfixes
  * fix problem with set reference message shortcut
  * fix loading decodings and centralized place for decodings
* Tue Oct 23 2018 mardnh@gmx.de
- Update to version 2.4.1
  * Add an option to disable automatic detection of interpretation
    parameters for newly loaded signals to the Edit menu
  Bugfixes
  * fix off by one error when creating a new label in analysis
  * fix crash when opening a project with saved dc correction setting
* Fri Oct 19 2018 mardnh@gmx.de
- Update to version 2.4.0
  * added font size zoom to table views (analysis/generator/simulator)
  * greatly enhance accuracy of automatic interpretation
  * added DC correction option to recording dialogs and as a new
    filter type in Interpretation
  Improvements
  * ignore case when searching for hex values in analysis
  * RSSI is now given in dBm
  Bugfixes
  * Fix display of RSSI indicator in Interpretation
* Sun Sep 30 2018 mardnh@gmx.de
- Update to version 2.3.0
  * added native support for BladeRF
  * added backward compatibility for SDRPlay < 2.13
  * improved UI for message type and label configuration in analysis
  * rename close all action to close all files for more clarity
  * added a close project action
- Build with support for BladeRF
* Thu Aug 30 2018 mardnh@gmx.de
- Update to version 2.2.4
  * fix scaling of modulated preview in modulation dialog
  * improve default parameters for PSK modulation in modulation
    dialog
* Mon Jul 30 2018 mpluskal@suse.com
- Use python macros when building
- Run spec-cleaner
* Sun Jul 29 2018 mardnh@gmx.de
- Update to version 2.2.3
  New features:
  * allow save and load of binary protocols (.bin files)
  * improve bootstrap of simulator messages
    + auto assign destination when dropping messages to simulator
    + show participant address in participant legend if present
    + auto assign participant address when clicking analyze button in
    analysis based on SRC address label
  * consider API changes of SDRPlay 2.13
  * also consider participant address (next to RSSI) when auto assigning
    participants in analysis
  * Clear button stays enabled during operation so e.g. recordings can be
    cleared live
  Bugfixes:
  * antenna selection is not saved when reopening dialog #494
  * hiding multiple rows at once in analysis not working properly #499
* Fri Jun 29 2018 mardnh@gmx.de
- Update to version 2.2.0
  * make message pause configurable in simulator
  * add padding when sending very short messages with soundcard
  * move .desktop file to data folder. Important if you build a package
    of URH
  * make relative external programs paths relative to project path
  * improve conditional compiling of native device extensions
  * improve device selection in options, use a table instead of a list
    view
  * improve python2 interpreter settings for GNU Radio backend with
    empty urh.ini
  * add alignment action to analysis
    alignment image
* Mon Jun 18 2018 mardnh@gmx.de
- Update to version 2.1.1
  * a bug was fixed where sample rate of a signal was not written
    correctly to wav file when exporting as wav
* Fri Jun  1 2018 mardnh@gmx.de
- Update to version 2.1.0
  Features:
  * The highlight of this release is a Command Line Interface (CLI)
  * Add export features #437
  * Make refin and refout configurable for CRC #439
  Fixes:
  * fix #441 (Reference signal is not kept when disabling and
    re-enabling "Mark diffs in protocol")
  * fix #442 (consider hidden zeros for show selection in interpretation)
  * fix #444 (Message Break error box popping up too early)
  * fix #448 (Include pyaudio in windows package for soundcard support)
* Mon May  7 2018 mardnh@gmx.de
- Update to version 2.0.4
  * Improve external program behaviour in Simulator
  * Improve simulator useability
  * Improve transcript for external programs
  * make endianness selectable in order column
  * UI improvements
  * add support for soundcards as new SDR device
  * Multi device support
  * add support for 24bit wav
* Mon Apr 23 2018 mardnh@gmx.de
- Update to version 2.0.2
  * Improve external program behaviour in Simulator
  * Improve simulator useability
  * Improve transcript for external programs
  * Make endianness selectable in order column
  * UI improvements
* Fri Mar 23 2018 mardnh@gmx.de
- Update to version 2.0.1
  * Bugfix release
* Wed Feb 28 2018 mardnh@gmx.de
- Update to version 2.0.0
  * Add Simulator mode
  * Performance and stability improvements:
  - improve accuracy when sending messages with short pauses
  - improve accuracy of protocol sniffer
  - allow setting lower frequencies for HackRF (#396)
  - consider latest changes of LimeSuite API (#397)
  - add timestamp to protocol sniffer output (#392)
  - improve performance of modulations
  - improve performance of filtering in analysis
  - improve performance when starting sending
  - improve send accuracy of HackRF
  - improve performance when filtering messages in Analysis
* Fri Jan 19 2018 mardnh@gmx.de
- Update to version 1.9.2
  * Add BCD (Binary Coded Decimal) as new display format
  * Make bit order configurable in analysis view table
  * Improved loading of protocol files
- Package svg version of the app-icon
* Tue Dec 19 2017 guillaume@opensuse.org
- Add more required runtime deps:
  * python3-pyzmq
  * python3-qt5
* Mon Dec 18 2017 mardnh@gmx.de
- Update to version 1.9.1
  * hotfix release that fixes an error with HackRF receiving
* Sun Dec 17 2017 mardnh@gmx.de
- Update to version 1.9.0
  * added native support for SDRplay
  * improved performance for continuous send mode
  * added collapsable comboboxes to device dialog
* Mon Dec  4 2017 mardnh@gmx.de
- Update to version 1.8.17
  * show warning at bottom if no project loaded
  * if no project is opened an new project is created, add
    currently opnened files to new project
  * add --version flag to command line script
* Thu Nov 30 2017 mardnh@gmx.de
- Update to version 1.8.16
  * This release fixes an issue on Windows where processes ended
    with an error.
  * The NetworkSDR can now be used in continuous send mode
* Mon Nov 27 2017 mardnh@gmx.de
- Update to version 1.8.15
  * This release fixes a problem mentioned in #366 and #368
    with GNU Radio backend on Windows.
* Sun Nov 26 2017 mardnh@gmx.de
- Update to version 1.8.14
  * This release fixes an overflow error (#364) when modulating
    very long messages in Generator.
  * The highlight of this release is an enhanced spectrum analyzer
    (#365) with increased performance and a waterfall plot to have
    a different, time based perspective on the spectrum.
* Sat Nov 18 2017 mardnh@gmx.de
- Update to version 1.8.13
* Thu Nov 16 2017 mardnh@gmx.de
- Update to version 1.8.12
  * added a CSV import wizard for generic support of USB oscilloscopes
* Mon Nov 13 2017 mardnh@gmx.de
- Update to version 1.8.11
  The following issues were fixed in this release:
  * crash when entering bits on empty position in Analysis/Generation
  * bandpass filter can now also work with negative frequencies
  * bandpass filter operations now run in a separate process and
    can be canceled with the ESC button
  * added a csv import to work with USB oscilloscopes
  * added a advanced modulation menu in Interpretation where a
    minimum message length for ASK can be configured
* Thu Nov  9 2017 mardnh@gmx.de
- Remove macros %%desktop_database_post and %%icon_theme_cache_post
  from %%post and %%postun section. These macros are not longer
  needed.
* Sun Nov  5 2017 jengelh@inai.de
- Update summary.
* Sun Oct 22 2017 mardnh@gmx.de
- Update to version 1.8.10
* Sun Oct 22 2017 mardnh@gmx.de
- Initial package, version 1.8.8
